aboutsummaryrefslogtreecommitdiffstats
path: root/src/junit/com/jogamp
diff options
context:
space:
mode:
authorSven Gothel <[email protected]>2014-10-04 02:47:13 +0200
committerSven Gothel <[email protected]>2014-10-04 02:47:13 +0200
commit2afb19885905285399b90f9a489fba8d2a09454e (patch)
tree4a9802b6ffdd238190230f3f6653594dafbfb1d8 /src/junit/com/jogamp
parent0d9efa74b10ea29d33ecc9c2b9f06bb2209d96ca (diff)
SingletonJunitCase: Increase TO 12 -> 15 mins, only sleep for 1 poll period (500 ms) per JVM after test class (cooperative w/ other JVM test instances)
Diffstat (limited to 'src/junit/com/jogamp')
-rw-r--r--src/junit/com/jogamp/common/util/locks/TestSingletonServerSocket02.java3
-rw-r--r--src/junit/com/jogamp/junit/util/SingletonJunitCase.java6
2 files changed, 3 insertions, 6 deletions
diff --git a/src/junit/com/jogamp/common/util/locks/TestSingletonServerSocket02.java b/src/junit/com/jogamp/common/util/locks/TestSingletonServerSocket02.java
index d29abf0..b96f1b4 100644
--- a/src/junit/com/jogamp/common/util/locks/TestSingletonServerSocket02.java
+++ b/src/junit/com/jogamp/common/util/locks/TestSingletonServerSocket02.java
@@ -29,9 +29,6 @@ package com.jogamp.common.util.locks;
import java.io.IOException;
-import org.junit.Assert;
-import org.junit.AfterClass;
-import org.junit.BeforeClass;
import org.junit.Test;
import org.junit.FixMethodOrder;
import org.junit.runners.MethodSorters;
diff --git a/src/junit/com/jogamp/junit/util/SingletonJunitCase.java b/src/junit/com/jogamp/junit/util/SingletonJunitCase.java
index 2552142..7fb5fea 100644
--- a/src/junit/com/jogamp/junit/util/SingletonJunitCase.java
+++ b/src/junit/com/jogamp/junit/util/SingletonJunitCase.java
@@ -40,7 +40,7 @@ public abstract class SingletonJunitCase extends JunitTracer {
public static final String SINGLE_INSTANCE_LOCK_FILE = "SingletonTestCase.lock";
public static final int SINGLE_INSTANCE_LOCK_PORT = 59999;
- public static final long SINGLE_INSTANCE_LOCK_TO = 12*60*1000; // wait up to 12 mins
+ public static final long SINGLE_INSTANCE_LOCK_TO = 15*60*1000; // wait up to 15 mins
public static final long SINGLE_INSTANCE_LOCK_POLL = 500; // poll every 500 ms
private static SingletonInstance singletonInstance = null; // system wide lock via port locking
@@ -70,8 +70,8 @@ public abstract class SingletonJunitCase extends JunitTracer {
System.err.println("++++ Test Singleton.unlock()");
singletonInstance.unlock();
try {
- // 3 s sleep, allowing other instances to pick-up socket
- Thread.sleep(3 * 2 * SINGLE_INSTANCE_LOCK_POLL);
+ // allowing other JVM instances to pick-up socket
+ Thread.sleep( SINGLE_INSTANCE_LOCK_POLL );
} catch (final InterruptedException e) { }
}
}